==> nextcloud-31.0.4.tgz: nextcloud/apps/twofactor_backupcodes/l10n/en_GB.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "You created two-factor backup codes for your account",
    "Second-factor backup codes" : "Second-factor backup codes",
    "Generate backup codes" : "Generate backup codes",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor.",
    "Backup code" : "Backup code",
    "Use backup code" : "Use backup code",
    "Two factor backup codes" : "Two factor backup codes",
    "A two-factor auth backup codes provider" : "A two-factor auth backup codes provider",
    "An error occurred while generating your backup codes" : "An error occurred while generating your backup codes",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Backup codes have been generated. {used} of {total} codes have been used.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later." : "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later.",
    "Save backup codes" : "Save backup codes",
    "Print backup codes" : "Print backup codes",
    "Regenerate backup codes" : "Regenerate backup codes",
    "If you regenerate backup codes, you automatically invalidate old codes." : "If you regenerate backup codes, you automatically invalidate old codes.",
    "{name} backup codes" : "{name} backup codes",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Use one of the backup codes you saved when setting up two-factor authentication.",
    "Submit" : "Submit",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.11.tgz: nextcloud/apps/twofactor_backupcodes/l10n/en_GB.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "You created two-factor backup codes for your account",
    "Second-factor backup codes" : "Second-factor backup codes",
    "Generate backup codes" : "Generate backup codes",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor.",
    "Backup code" : "Backup code",
    "Use backup code" : "Use backup code",
    "Two factor backup codes" : "Two factor backup codes",
    "A two-factor auth backup codes provider" : "A two-factor auth backup codes provider",
    "An error occurred while generating your backup codes" : "An error occurred while generating your backup codes",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Backup codes have been generated. {used} of {total} codes have been used.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later." : "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later.",
    "List of backup codes" : "List of backup codes",
    "Regenerate backup codes" : "Regenerate backup codes",
    "Print backup codes" : "Print backup codes",
    "Save backup codes" : "Save backup codes",
    "If you regenerate backup codes, you automatically invalidate old codes." : "If you regenerate backup codes, you automatically invalidate old codes.",
    "{name} backup codes" : "{name} backup codes",
    "Unable to open a new tab for printing" : "Unable to open a new tab for printing",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Use one of the backup codes you saved when setting up two-factor authentication.",
    "Submit" : "Submit"
},
"nplurals=2; plural=(n != 1);");
